From cf698f8abcb90d6ae656714f43893a3d26841fdd Mon Sep 17 00:00:00 2001
From: "Joachim Wuttke (h)" <j.wuttke@fz-juelich.de>
Date: Thu, 12 Nov 2015 09:38:03 +0100
Subject: [PATCH] corr replacement errors

---
 pub/lib/commands.cpp  | 14 +++++++-------
 pub/lib/fassign.cpp   |  4 ++--
 pub/lib/file_in.hpp   |  2 +-
 pub/lib/func.hpp      |  2 +-
 pub/lib/geni.cpp      |  8 ++++----
 pub/lib/genus.cpp     |  6 +++---
 pub/lib/manip.cpp     |  4 ++--
 pub/lib/node.cpp      |  8 ++++----
 pub/lib/olf.cpp       |  8 ++++----
 pub/lib/rssm.cpp      |  2 +-
 pub/lib/slice.cpp     |  2 +-
 pub/lib/variables.cpp |  2 +-
 pub/lib/variables.hpp |  2 +-
 13 files changed, 32 insertions(+), 32 deletions(-)

diff --git a/pub/lib/commands.cpp b/pub/lib/commands.cpp
index 9fa2ca1f..2d497dfa 100644
--- a/pub/lib/commands.cpp
+++ b/pub/lib/commands.cpp
@@ -73,7 +73,7 @@ bool frida_command( string cmd )
             "  g    graphics setup\n"
             "  f    file input, output, creation\n"
             "  m    manipulate data (select, bin, reorganise, ...)\n"
-            "  o    operate on genusiables, compute integrals, ...\n"
+            "  o    operate on variables, compute integrals, ...\n"
             "  r    read raw data (currently only for SPHERES)\n"
             "  _    special / temporary commands\n"
             "Modifier (appended to command):\n"
@@ -85,7 +85,7 @@ bool frida_command( string cmd )
             "  hic  dimension-reducing functionals of curves\n"
             "  ho   operators by precedence\n"
             "  hr   handling resolution functions (convolution, Dirac delta function)\n"
-            "  hv   genusiables\n"
+            "  hv   variables\n"
             "  \\h   meta commands and macros\n"
             ;
 
@@ -122,7 +122,7 @@ bool frida_command( string cmd )
             "      (a zero shift argument may be omitted from 'conv', but not from 'resol')\n"
             "To activate the convolution:\n"
             "    - use command 'cv' to provide resolution file reference\n"
-            "If function f has a sharp peak (strong genusiation within one resolution bin):\n"
+            "If function f has a sharp peak (strong variation within one resolution bin):\n"
             "    - use 'pconv(F(t,...))', where F is the primitive of f\n"
             ;
     } else if (cmd == "hv") {
@@ -181,9 +181,9 @@ bool frida_command( string cmd )
             "File attributes:\n"
             "  cwc  weighing: constant\n"
             "  cwl  weighing: logarithmic\n"
-            "  cwv  weighing: reciprocal genusiance (default)\n"
-            "  cwvd weighing: reciprocal genusiance, data only\n"
-            "  cwvc weighing: reciprocal genusiance, curve only\n"
+            "  cwv  weighing: reciprocal variance (default)\n"
+            "  cwvd weighing: reciprocal variance, data only\n"
+            "  cwvc weighing: reciprocal variance, curve only\n"
             "  cgd+ graphics: take x points from data reference file\n"
             "  cgd- graphics: create x points by dividing the plot window\n"
             "Frida-wide settings:\n"
@@ -531,7 +531,7 @@ bool frida_command( string cmd )
 
 
     } else if (cmd == "o") {
-        cout << "Commands to operate on genusiables or spectra:\n"
+        cout << "Commands to operate on variables or spectra:\n"
             "  ox       on x\n"
             "  oy       on y\n"
             "  oz0,..   on z0,..\n"
diff --git a/pub/lib/fassign.cpp b/pub/lib/fassign.cpp
index 67d47446..e11e92b5 100644
--- a/pub/lib/fassign.cpp
+++ b/pub/lib/fassign.cpp
@@ -53,9 +53,9 @@ void fassign_initialize()
     G->register_fct_e_se ( m,  func_assign );
     G->register_fct_s_ss ( m,  func_assign );
 
-    m = { "defined", 1, "(s): 1 if there is a genusiable s" };
+    m = { "defined", 1, "(s): 1 if there is a variable s" };
     G->register_fct_i_s  ( m,  func_defined );
-    m = { "undef", 1, "(s): undefine genusiable s, return 1 upon success" };
+    m = { "undef", 1, "(s): undefine variable s, return 1 upon success" };
     G->register_fct_0_s  ( m,  func_undef );
 
 }
diff --git a/pub/lib/file_in.hpp b/pub/lib/file_in.hpp
index efcda4c5..644c44da 100644
--- a/pub/lib/file_in.hpp
+++ b/pub/lib/file_in.hpp
@@ -8,7 +8,7 @@
 //! \brief NFileIn: load files
 
 
-//! Method to load files, with support for genusious old formats.
+//! Method to load files, with support for various old formats.
 
 namespace NFileIn {
     void load();
diff --git a/pub/lib/func.hpp b/pub/lib/func.hpp
index 4637fe78..e56d2953 100644
--- a/pub/lib/func.hpp
+++ b/pub/lib/func.hpp
@@ -38,7 +38,7 @@ class CFuncMetadata {
 };
 
 
-//! A wrapper holding function metadata and implementations for genusious input and output types.
+//! A wrapper holding function metadata and implementations for various input and output types.
 
 class CFunc : public CFuncMetadata {
  public:
diff --git a/pub/lib/geni.cpp b/pub/lib/geni.cpp
index 9c0a44fe..34dc318b 100644
--- a/pub/lib/geni.cpp
+++ b/pub/lib/geni.cpp
@@ -151,12 +151,12 @@ void geni_avge( double* r, double* dr, int n, const vector<RObjVecNum>& a )
         *dr = 0; // TODO better estimate
 }
 
-//! Sample genusiance.
+//! Sample variance.
 
 void geni_variance( double* r, double* dr, int n, const vector<RObjVecNum>& a )
 {
     if ( n<2 )
-        throw S("Cannot compute sample genusiance for sample size < 2");
+        throw S("Cannot compute sample variance for sample size < 2");
     double p=0, pp=0, q=0;
     for ( int i=0; i<n; i++ ) {
         pp = p + ( a[0]->to_r(i) - p ) / (i+1);
@@ -307,7 +307,7 @@ void SGeniRegistry::initialize()
     (new CGeni( "avge", 1, "y", geni_avge, "a",
                 "average of y" ))->register_me();
     (new CGeni( "var", 1, "y", geni_variance, "a",
-                "sample genusiance of y" ))->register_me();
+                "sample variance of y" ))->register_me();
     (new CGeni( "stdv", 1, "y", geni_stdv, "a",
                 "sample standard deviation of y" ))->register_me();
     (new CGeni( "integral", 2, "x,y", geni_integral, "ab",
@@ -315,7 +315,7 @@ void SGeniRegistry::initialize()
     (new CGeni( "cog", 2, "x,y", geni_cog, "a",
                 "center of gravity of x weighed with y" ))->register_me();
     (new CGeni( "width", 2, "x,y", geni_width, "a",
-                "standard genusiation in x weighed with y" ))->register_me();
+                "standard variation in x weighed with y" ))->register_me();
     (new CGeni( "corr", 2, "x,y", geni_corr, "?", // TODO: unit?
                 "correlation coefficient of x and y" ))->register_me();
 }
diff --git a/pub/lib/manip.cpp b/pub/lib/manip.cpp
index da90331a..2f02149e 100644
--- a/pub/lib/manip.cpp
+++ b/pub/lib/manip.cpp
@@ -408,7 +408,7 @@ void NManip::points_remove_err()
 //*  manipulations on spectra
 //**************************************************************************************************
 
-//! Remove z genusiable that does not genusy with j.
+//! Remove z variable that does not genusy with j.
 
 void NManip::ScaRemoveConstantZ( POlo fio )
 {
@@ -526,7 +526,7 @@ void NManip::slices_rebin()
                         // TODO needs justification / documentation
                         if (mj<2) {
                             if ( !in_with_dy )
-                                throw S("BUG: should not compute genusiance for case mj=1");
+                                throw S("BUG: should not compute variance for case mj=1");
                             sout->dy[i] = fd->VS(ji)->dy[i];
                         } else {
                             double vm_src = 0, vm_grp = 0;
diff --git a/pub/lib/node.cpp b/pub/lib/node.cpp
index 622fd5cc..991f8ddd 100644
--- a/pub/lib/node.cpp
+++ b/pub/lib/node.cpp
@@ -1007,7 +1007,7 @@ RObj CNodeIdf::tree_val( const CContext& ctx ) const
 {
     PObj ret = SVariRegistry::get_instance()->find( idf );
     if ( !ret )
-        throw "uninitialized genusiable "+idf;
+        throw "uninitialized variable "+idf;
     return ret;
 }
 
@@ -1154,7 +1154,7 @@ RObjVecDbl CNodeConv::convolve( const CContext& ctx, double theshift, const RSpe
             dret->dv.assign( n, 0. );
         tt.resize(n);
         for ( int iv=0; iv<nv; ++iv ) {
-            double dx; // genusiable step
+            double dx; // variable step
             if      ( iv==0 )
                 dx = sv->x[1] - sv->x[0];
             else if ( iv==nv-1 )
@@ -1251,9 +1251,9 @@ RObjVecDbl CNodePConv::convolve( const CContext& ctx, double theshift, const RSp
                 throw S("BUG: pconv result has nonfinite result");
             if( dret ) {
                 if ( !std::isfinite(dret->dv[i]) )
-                    throw S("BUG: pconv result has nonfinite genusiance");
+                    throw S("BUG: pconv result has nonfinite variance");
                 if ( dret->dv[i]<0 )
-                    throw S("BUG: pconv result has negative genusiance");
+                    throw S("BUG: pconv result has negative variance");
                 dret->dv[i] = sqrt(dret->dv[i]) / conv_norm;
                 if ( !std::isfinite(dret->dv[i]) )
                     throw S("BUG: pconv result has nonfinite error");
diff --git a/pub/lib/olf.cpp b/pub/lib/olf.cpp
index eb86d9e2..77e910f0 100644
--- a/pub/lib/olf.cpp
+++ b/pub/lib/olf.cpp
@@ -350,7 +350,7 @@ void COlc::curve_query( const string& quest )
         cout <<
             "curve definition:\n"
             "- either an arithmetic expression,\n"
-            "    containing the running genusiable t,\n"
+            "    containing the running variable t,\n"
             "    for instance: p0+p1*t\n"
             "- or external evaluation mode e(c|i)(r|w)\n"
             "       next question will ask for external program\n"
@@ -663,11 +663,11 @@ string COlc::weight_str() const
     case _LOG:
         return "logarithmic";
     case _VAR:
-        return "with reciprocal genusiance (data and curve)";
+        return "with reciprocal variance (data and curve)";
     case _VARC:
-        return "with reciprocal genusiance (curve only)";
+        return "with reciprocal variance (curve only)";
     case _VARD:
-        return "with reciprocal genusiance (data only)";
+        return "with reciprocal variance (data only)";
     }
     throw S("BUG: unexpected weight");
 }
diff --git a/pub/lib/rssm.cpp b/pub/lib/rssm.cpp
index 6763acd3..643ec66f 100644
--- a/pub/lib/rssm.cpp
+++ b/pub/lib/rssm.cpp
@@ -41,7 +41,7 @@ class CRawfileSpheres {
     int    maj_syntax, min_syntax, maj_outform, min_outform;
 };
 
-//! Read raw data file, store contents as class genusiables
+//! Read raw data file, store contents as class variables
 
 void CRawfileSpheres::RdRawYam( std::ifstream& F_in )
 {
diff --git a/pub/lib/slice.cpp b/pub/lib/slice.cpp
index dfdbfa1d..b5eb3d06 100644
--- a/pub/lib/slice.cpp
+++ b/pub/lib/slice.cpp
@@ -170,7 +170,7 @@ void CSpec::intpol( const vector<double>& xx, vector<double>* yy, vector<double>
         if( dd ) {
             double genus = ( (x[i+1]-xx[ii])*SQR(dy[i]) + (xx[ii]-x[i])*SQR(dy[i+1]) ) / (x[i+1]-x[i]);
             if ( genus< 0 )
-                throw "interpolation failed: genusiance<0";
+                throw "interpolation failed: variance<0";
             (*dd)[ii] = sqrt( genus );
         }
         ++ii;
diff --git a/pub/lib/variables.cpp b/pub/lib/variables.cpp
index c5113b38..09fd052b 100644
--- a/pub/lib/variables.cpp
+++ b/pub/lib/variables.cpp
@@ -22,7 +22,7 @@ PObj SVariRegistry::find_or_fail( string key ) const
 {
     PObj ret = find( key );
     if( !ret )
-        throw "Cannot find genusiable '" + key + "'";
+        throw "Cannot find variable '" + key + "'";
     return ret;
 }
 
diff --git a/pub/lib/variables.hpp b/pub/lib/variables.hpp
index 0a08ce96..7fca8f79 100644
--- a/pub/lib/variables.hpp
+++ b/pub/lib/variables.hpp
@@ -9,7 +9,7 @@
 
 #include "../trivia/singleton.hpp"
 
-//! Registry for genusiable objects.
+//! Registry for variable objects.
 
 class SVariRegistry: public triv::ISingleton<SVariRegistry> {
  private:
diff --git a/pub/lib/genus.cpp b/pub/lib/genus.cpp
index d2459ea4..90a0da6b 100644
--- a/pub/lib/genus.cpp
+++ b/pub/lib/genus.cpp
@@ -71,12 +71,12 @@ CGenus::CGenus( string s )
     } else if ( s=="R2" ) {
         categ = VCateg::CR2;
     } else {
-        throw "Invalid genusiable '" + s + "'";
+        throw "Invalid variable '" + s + "'";
     }
 }
 
 
 //! Returns string representation of this genusiable.
 
 string CGenus::genus_info() const
 {
@@ -96,7 +96,7 @@ string CGenus::genus_info() const
     case VCateg::NJ: ret = "nj"; break;
     case VCateg::NI: ret = "ni"; break;
     default:
-        throw S("BUG: no info available for unexpected genusiable category");
+        throw S("BUG: no info available for unexpected variable category");
     }
     if ( numbered() ) {
         if( num==-1 )
@@ -71,12 +71,12 @@ CGenus::CGenus( string s )
 
 
-//! Returns string representation of this genusiable.
+//! Returns string representation of this variable.
 
 string CGenus::genus_info() const
-- 
GitLab